@@ -1,7 +1,6 @@
 #' @name wb_load
 #' @title Load an existing .xlsx file
 #' @param file A path to an existing .xlsx or .xlsm file
-#' @param xlsxFile alias for file
 #' @param sheet optional sheet parameter. if this is applied, only the selected
 #' sheet will be loaded.
 #' @param data_only mode to import if only a data frame should be returned. This
@@ -12,6 +11,7 @@
 #' chain will be created upon the next time the worksheet is loaded in
 #' spreadsheet software. Keeping it, might only speed loading time in said
 #' software.
+#' @param ... additional arguments
 #' @description  wb_load returns a workbook object conserving styles and
 #' formatting of the original .xlsx file.
 #' @details A warning is displayed if an xml namespace for main is found in the
@@ -32,13 +32,20 @@
 #' wb$add_worksheet("A new worksheet")
 wb_load <- function(
     file,
-    xlsxFile = NULL,
     sheet,
     data_only = FALSE,
-    calc_chain = FALSE
+    calc_chain = FALSE,
+    ...
 ) {
 
-  file <- xlsxFile %||% file
+  xlsx_file <- list(...)$xlsx_file
+  standardize_case_names(...)
+
+  if (!is.null(xlsx_file)) {
+    .Deprecated(old = "xlsx_file", new = "file", package = "openxlsx2")
+    file <- xlsx_file %||% file
+  }
+
   file <- getFile(file)
 
   if (!file.exists(file)) {
@@ -136,7 +143,7 @@ wb_load <- function(
   on.exit(
     unlink(
       # TODO: this removes all files, the folders remain. grep instead grep_xml?
-      grep_xml("media|vmlDrawing|customXml|comment|embeddings|vbaProject|person", ignore.case = TRUE, invert = TRUE),
+      grep_xml("media|vmlDrawing|customXml|embeddings|vbaProject", ignore.case = TRUE, invert = TRUE),
       recursive = TRUE, force = TRUE
     ),
     add = TRUE
@@ -304,7 +311,7 @@ wb_load <- function(
         overrideAttr <- as.data.frame(do.call("rbind", override))
         xmls <- basename(unlist(overrideAttr$PartName))
         drawings <- grep("drawing", xmls, value = TRUE)
-        wb$add_worksheet(sheets$name[i], visible = is_visible[i], hasDrawing = !is.na(drawings[i]))
+        wb$add_worksheet(sheets$name[i], visible = is_visible[i], has_drawing = !is.na(drawings[i]))
       }
     }
 
@@ -1091,10 +1098,17 @@ wb_load <- function(
 
         comments <- lapply(comments, function(x) {
           text <- xml_node(x, "comment", "text")
-          list(
-            style = xml_node(text, "text", "r", "rPr"),
-            comments = xml_node(text, "text", "r", "t")
-          )
+          if (all(xml_node_name(x, "comment", "text") == "t")) {
+            list(
+              style = FALSE,
+              comments = xml_node(text, "text", "t")
+            )
+          } else {
+            list(
+              style = xml_node(text, "text", "r", "rPr"),
+              comments = xml_node(text, "text", "r", "t")
+            )
+          }
         })
 
         wb$comments[[comment_xml]] <- lapply(seq_along(comments), function(j) {
@@ -1111,19 +1125,11 @@ wb_load <- function(
 
     ## Threaded comments
     if (length(threadCommentsXML) > 0) {
-      threadCommentsXMLrelationship <- lapply(xml, function(x) grep("threadedComment[0-9]+\\.xml", x, value = TRUE))
-      hasThreadComments <- lengths(threadCommentsXMLrelationship) > 0
-      if (any(hasThreadComments)) {
-        for (i in seq_along(xml)) {
-          if (hasThreadComments[i]) {
-            target <- apply_reg_match(threadCommentsXMLrelationship[[i]], '(?<=Target=").*?"')
-            target <- basename(gsub('"$', "", target))
 
-            wb$threadComments[[i]] <- grep(target, threadCommentsXML, value = TRUE)
-
-          }
-        }
+      if (lengths(threadCommentsXML)) {
+        wb$threadComments <- lapply(threadCommentsXML, read_xml, pointer = FALSE)
       }
+
       wb$append(
         "Content_Types",
         sprintf('<Override PartName="/xl/threadedComments/%s" ContentType="application/vnd.ms-excel.threadedcomments+xml"/>',
@@ -1133,7 +1139,8 @@ wb_load <- function(
 
     ## Persons (needed for Threaded Comment)
     if (length(personXML) > 0) {
-      wb$persons <- personXML
+      wb$persons <- read_xml(personXML, pointer = FALSE)
+
       wb$append(
         "Content_Types",
         '<Override PartName="/xl/persons/person.xml" ContentType="application/vnd.ms-excel.person+xml"/>'
