@@ -79,8 +79,8 @@ import_styles <- function(x) {
 #' @description
 #' Border styles can any of the following: "thin", "thick", "slantDashDot", "none", "mediumDashed", "mediumDashDot", "medium", "hair", "double", "dotted", "dashed", "dashedDotDot", "dashDot"
 #' Border colors are of the following type: c(rgb="FF000000")
-#' @param diagonalDown x
-#' @param diagonalUp x
+#' @param diagonal_down x
+#' @param diagonal_up x
 #' @param outline x
 #' @param bottom X
 #' @param bottom_color X
@@ -100,8 +100,8 @@ import_styles <- function(x) {
 #'
 #' @export
 create_border <- function(
-    diagonalDown   = "",
-    diagonalUp     = "",
+    diagonal_down  = "",
+    diagonal_up    = "",
     outline        = "",
     bottom         = NULL,
     bottom_color   = NULL,
@@ -120,7 +120,7 @@ create_border <- function(
     ...
 ) {
 
-  standardize_color_names(...)
+  standardize(...)
 
   if (!is.null(left_color))     left_color     <- xml_node_create("color", xml_attributes = left_color)
   if (!is.null(right_color))    right_color    <- xml_node_create("color", xml_attributes = right_color)
@@ -154,8 +154,8 @@ create_border <- function(
     right            = right,
     top              = top,
     bottom           = bottom,
-    diagonalDown     = diagonalDown,
-    diagonalUp       = diagonalUp,
+    diagonalDown     = diagonal_down,
+    diagonalUp       = diagonal_up,
     diagonal         = diagonal,
     vertical         = vertical,
     horizontal       = horizontal,
@@ -198,7 +198,7 @@ create_numfmt <- function(numFmtId, formatCode) {
 #' @param strike strike
 #' @param sz font size: default "11",
 #' @param u underline
-#' @param vertAlign vertical alignment
+#' @param vert_align vertical alignment
 #' @param ... ...
 #' @examples
 #' font <- create_font()
@@ -211,25 +211,25 @@ create_numfmt <- function(numFmtId, formatCode) {
 #' # cat(col("Test"))
 #' @export
 create_font <- function(
-    b         = "",
-    charset   = "",
-    color     = wb_color(hex = "FF000000"),
-    condense  = "",
-    extend    = "",
-    family    = "2",
-    i         = "",
-    name      = "Calibri",
-    outline   = "",
-    scheme    = "minor",
-    shadow    = "",
-    strike    = "",
-    sz        = "11",
-    u         = "",
-    vertAlign = "",
+    b          = "",
+    charset    = "",
+    color      = wb_color(hex = "FF000000"),
+    condense   = "",
+    extend     = "",
+    family     = "2",
+    i          = "",
+    name       = "Calibri",
+    outline    = "",
+    scheme     = "minor",
+    shadow     = "",
+    strike     = "",
+    sz         = "11",
+    u          = "",
+    vert_align = "",
     ...
 ) {
 
-  standardize_color_names(...)
+  standardize(...)
 
   if (b != "") {
     b <- xml_node_create("b", xml_attributes = c("val" = as_xml_attr(b)))
@@ -289,8 +289,8 @@ create_font <- function(
     u <- xml_node_create("u", xml_attributes = c("val" = as_xml_attr(u)))
   }
 
-  if (vertAlign != "") {
-    vertAlign <- xml_node_create("vertAlign", xml_attributes = c("val" = as_xml_attr(vertAlign)))
+  if (vert_align != "") {
+    vert_align <- xml_node_create("vertAlign", xml_attributes = c("val" = as_xml_attr(vert_align)))
   }
 
   df_font <- data.frame(
@@ -308,7 +308,7 @@ create_font <- function(
     strike           = strike,
     sz               = sz,
     u                = u,
-    vertAlign        = vertAlign,
+    vertAlign        = vert_align,
     stringsAsFactors = FALSE
   )
   font <- write_font(df_font)
@@ -370,23 +370,23 @@ create_fill <- function(
 
 # TODO can be further generalized with additional xf attributes and children
 #' create_cell_style
-#' @param borderId dummy
-#' @param fillId dummy
-#' @param fontId dummy
-#' @param numFmtId a numFmt ID for a builtin style
-#' @param pivotButton dummy
-#' @param quotePrefix dummy
-#' @param xfId dummy
+#' @param border_id dummy
+#' @param fill_id dummy
+#' @param font_id dummy
+#' @param num_fmt_id a numFmt ID for a builtin style
+#' @param pivot_button dummy
+#' @param quote_prefix dummy
+#' @param xf_id dummy
 #' @param horizontal dummy
 #' @param indent dummy
-#' @param justifyLastLine dummy
-#' @param readingOrder dummy
-#' @param relativeIndent dummy
-#' @param shrinkToFit dummy
-#' @param textRotation dummy
+#' @param justify_last_line dummy
+#' @param reading_order dummy
+#' @param relative_indent dummy
+#' @param shrink_to_fit dummy
+#' @param text_rotation dummy
 #' @param vertical dummy
-#' @param wrapText dummy
-#' @param extLst dummy
+#' @param wrap_text dummy
+#' @param ext_lst dummy
 #' @param hidden dummy
 #' @param locked dummy
 #' @param horizontal alignment can be "", "center", "right"
@@ -426,51 +426,53 @@ create_fill <- function(
 #'  | "49" | "@"                         |
 #' @export
 create_cell_style <- function(
-    borderId        = "",
-    fillId          = "",
-    fontId          = "",
-    numFmtId        = "",
-    pivotButton     = "",
-    quotePrefix     = "",
-    xfId            = "",
-    horizontal      = "",
-    indent          = "",
-    justifyLastLine = "",
-    readingOrder    = "",
-    relativeIndent  = "",
-    shrinkToFit     = "",
-    textRotation    = "",
-    vertical        = "",
-    wrapText        = "",
-    extLst          = "",
-    hidden          = "",
-    locked          = "",
+    border_id         = "",
+    fill_id           = "",
+    font_id           = "",
+    num_fmt_id        = "",
+    pivot_button      = "",
+    quote_prefix      = "",
+    xf_id             = "",
+    horizontal        = "",
+    indent            = "",
+    justify_last_line = "",
+    reading_order     = "",
+    relative_indent   = "",
+    shrink_to_fit     = "",
+    text_rotation     = "",
+    vertical          = "",
+    wrap_text         = "",
+    ext_lst           = "",
+    hidden            = "",
+    locked            = "",
     ...
 ) {
-  n <- length(numFmtId)
+  n <- length(num_fmt_id)
 
+  arguments <- c(ls(), "is_cell_style_xf")
+  standardize_case_names(..., arguments = arguments)
   args <- list(...)
 
   is_cell_style_xf <- isTRUE(args$is_cell_style_xf)
 
   applyAlignment <- ""
-  if (any(horizontal != "") || any(textRotation != "") || any(vertical != "")) applyAlignment <- "1"
+  if (any(horizontal != "") || any(text_rotation != "") || any(vertical != "")) applyAlignment <- "1"
   if (is_cell_style_xf) applyAlignment <- "0"
 
   applyBorder <- ""
-  if (any(borderId != "")) applyBorder <- "1"
-  if (is_cell_style_xf && isTRUE(borderId == "")) applyBorder <- "0"
+  if (any(border_id != "")) applyBorder <- "1"
+  if (is_cell_style_xf && isTRUE(border_id == "")) applyBorder <- "0"
 
   applyFill <- ""
-  if (any(fillId != "")) applyFill <- "1"
-  if (is_cell_style_xf && isTRUE(fillId == "")) applyFill <- "0"
+  if (any(fill_id != "")) applyFill <- "1"
+  if (is_cell_style_xf && isTRUE(fill_id == "")) applyFill <- "0"
 
   applyFont <- ""
-  if (any(fontId != "")) applyFont <- "1"
-  if (is_cell_style_xf && isTRUE(fontId > "1")) applyFont <- "0"
+  if (any(font_id != "")) applyFont <- "1"
+  if (is_cell_style_xf && isTRUE(font_id > "1")) applyFont <- "0"
 
   applyNumberFormat <- ""
-  if (any(numFmtId != "")) applyNumberFormat <- "1"
+  if (any(num_fmt_id != "")) applyNumberFormat <- "1"
   if (is_cell_style_xf) applyNumberFormat <- "0"
 
   applyProtection <- ""
@@ -485,23 +487,23 @@ create_cell_style <- function(
     applyFont         = rep(applyFont, n),
     applyNumberFormat = rep(applyNumberFormat, n),
     applyProtection   = rep(applyProtection, n),
-    borderId          = rep(as_xml_attr(borderId), n),
-    fillId            = rep(as_xml_attr(fillId), n),
-    fontId            = rep(as_xml_attr(fontId), n),
-    numFmtId          = as_xml_attr(numFmtId),
-    pivotButton       = rep(as_xml_attr(pivotButton), n),
-    quotePrefix       = rep(as_xml_attr(quotePrefix), n),
-    xfId              = rep(as_xml_attr(xfId), n),
+    borderId          = rep(as_xml_attr(border_id), n),
+    fillId            = rep(as_xml_attr(fill_id), n),
+    fontId            = rep(as_xml_attr(font_id), n),
+    numFmtId          = as_xml_attr(num_fmt_id),
+    pivotButton       = rep(as_xml_attr(pivot_button), n),
+    quotePrefix       = rep(as_xml_attr(quote_prefix), n),
+    xfId              = rep(as_xml_attr(xf_id), n),
     horizontal        = rep(as_xml_attr(horizontal), n),
     indent            = rep(as_xml_attr(indent), n),
-    justifyLastLine   = rep(as_xml_attr(justifyLastLine), n),
-    readingOrder      = rep(as_xml_attr(readingOrder), n),
-    relativeIndent    = rep(as_xml_attr(relativeIndent), n),
-    shrinkToFit       = rep(as_xml_attr(shrinkToFit), n),
-    textRotation      = rep(as_xml_attr(textRotation), n),
+    justifyLastLine   = rep(as_xml_attr(justify_last_line), n),
+    readingOrder      = rep(as_xml_attr(reading_order), n),
+    relativeIndent    = rep(as_xml_attr(relative_indent), n),
+    shrinkToFit       = rep(as_xml_attr(shrink_to_fit), n),
+    textRotation      = rep(as_xml_attr(text_rotation), n),
     vertical          = rep(as_xml_attr(vertical), n),
-    wrapText          = rep(as_xml_attr(wrapText), n),
-    extLst            = rep(extLst, n),
+    wrapText          = rep(as_xml_attr(wrap_text), n),
+    extLst            = rep(ext_lst, n),
     hidden            = rep(as_xml_attr(hidden), n),
     locked            = rep(as_xml_attr(locked), n),
     stringsAsFactors  = FALSE
@@ -650,34 +652,39 @@ get_cell_styles <- function(wb, sheet, cell) {
   out
 }
 
-#' @name create_dxfs_style
-#' @title Create a custom formatting style
-#' @description Create a new style to apply to worksheet cells. Created styles have to be
+#' Create a custom formatting style
+#'
+#' @description
+#' Create a new style to apply to worksheet cells. Created styles have to be
 #' assigned to a workbook to use them
-#' @param font_name A name of a font. Note the font name is not validated. If fontName is NULL,
-#' the workbook base font is used. (Defaults to Calibri)
+#'
+#' @details
+#' It is possible to override border_color and border_style with {left, right, top, bottom}_color, {left, right, top, bottom}_style.
+#'
+#' @seealso [wb_add_style()]
+# TODO maybe font_name,font_size could be documented together.
+#' @param font_name A name of a font. Note the font name is not validated.
+#'   If `font_name` is `NULL`, the workbook `base_font` is used. (Defaults to Calibri), see [wb_get_base_font()]
 #' @param font_color Color of text in cell.  A valid hex color beginning with "#"
-#' or one of colors(). If fontColor is NULL, the workbook base font colors is used.
+#'   or one of colors(). If `font_color` is NULL, the workbook base font colors is used.
 #' (Defaults to black)
 #' @param font_size Font size. A numeric greater than 0.
-#' If fontSize is NULL, the workbook base font size is used. (Defaults to 11)
-#' @param numFmt Cell formatting. Some custom openxml format
-#' @param border NULL or TRUE
+#'   By default, the workbook base font size is used. (Defaults to 11)
+#' @param num_fmt Cell formatting. Some custom openxml format
+#' @param border `NULL` or `TRUE`
 #' @param border_color "black"
 #' @param border_style "thin"
-#' @param bgFill Cell background fill color.
-#' @param fgColor Cell foreground fill color.
-#' @param gradientFill An xml string beginning with `<gradientFill>` ...
+#' @param bg_fill Cell background fill color.
+#' @param fg_color Cell foreground fill color.
+#' @param gradient_fill An xml string beginning with `<gradientFill>` ...
 #' @param text_bold bold
 #' @param text_strike strikeout
 #' @param text_italic italic
 #' @param text_underline underline 1, true, single or double
-#' @param ... ...
-#' @details It is possible to override border_color and border_style with {left, right, top, bottom}_color, {left, right, top, bottom}_style.
+#' @param ... Additional arguments
 #' @return A dxfs style node
-#' @seealso [wb_add_style()]
 #' @examples
-#' # do not apply anthing
+#' # do not apply anything
 #' style1 <- create_dxfs_style()
 #'
 #' # change font color and background color
@@ -701,13 +708,13 @@ create_dxfs_style <- function(
     font_name      = NULL,
     font_size      = NULL,
     font_color     = NULL,
-    numFmt         = NULL,
+    num_fmt        = NULL,
     border         = NULL,
     border_color   = wb_color(getOption("openxlsx2.borderColor", "black")),
     border_style   = getOption("openxlsx2.borderStyle", "thin"),
-    bgFill         = NULL,
-    fgColor        = NULL,
-    gradientFill   = NULL,
+    bg_fill        = NULL,
+    fg_color       = NULL,
+    gradient_fill  = NULL,
     text_bold      = NULL,
     text_strike    = NULL,
     text_italic    = NULL,
@@ -715,10 +722,11 @@ create_dxfs_style <- function(
     ...
 ) {
 
-  standardize_color_names(...)
-
-  args <- list(...)
-  nams <- names(args)
+  arguments <- c(..., ls(),
+                 "left_color", "left_style", "right_color", "right_style",
+                 "top_color", "top_style", "bottom_color", "bottom_style"
+  )
+  standardize(..., arguments = arguments)
 
   if (is.null(font_color)) font_color <- ""
   if (is.null(font_size)) font_size <- ""
@@ -728,7 +736,7 @@ create_dxfs_style <- function(
   if (is.null(text_underline)) text_underline <- ""
 
   # found numFmtId=3 in MS365 xml not sure if this should be increased
-  if (!is.null(numFmt)) numFmt <- create_numfmt(3, numFmt)
+  if (!is.null(num_fmt)) num_fmt <- create_numfmt(3, num_fmt)
 
   font <- create_font(
     color = font_color, name = font_name,
@@ -738,34 +746,34 @@ create_dxfs_style <- function(
     family = "", scheme = ""
   )
 
-  if ("patternType" %in% nams) {
-    patternType <- args$patternType
+  if (exists("pattern_type")) {
+    pattern_type <- pattern_type
   } else {
-    patternType <- "solid"
+    pattern_type <- "solid"
   }
 
-  if (!is.null(bgFill) && !all(bgFill == "") || !is.null(gradientFill)) {
-    if (is.null(gradientFill)) {
+  if (!is.null(bg_fill) && !all(bg_fill == "") || !is.null(gradient_fill)) {
+    if (is.null(gradient_fill)) {
       # gradientFill is an xml string
-      gradientFill <- ""
+      gradient_fill <- ""
     } else {
-      patternType  <- ""
+      pattern_type  <- ""
     }
-    fill <- create_fill(patternType = patternType, bgColor = bgFill, fgColor = fgColor, gradientFill = gradientFill)
+    fill <- create_fill(patternType = pattern_type, bgColor = bg_fill, fgColor = fg_color, gradientFill = gradient_fill)
   } else {
     fill <- NULL
   }
 
   # untested
   if (!is.null(border)) {
-    left_color   <- if ("left_color" %in% nams) args$left_color else border_color
-    left_style   <- if ("left_style" %in% nams) args$left_style else border_style
-    right_color  <- if ("right_color" %in% nams) args$right_color else border_color
-    right_style  <- if ("right_style" %in% nams) args$right_style else border_style
-    top_color    <- if ("top_color" %in% nams) args$top_color else border_color
-    top_style    <- if ("top_style" %in% nams) args$top_style else border_style
-    bottom_color <- if ("bottom_color" %in% nams) args$bottom_color else border_color
-    bottom_style <- if ("bottom_style" %in% nams) args$bottom_style else border_style
+    left_color   <- if (exists("left_color"))   left_color   else border_color
+    left_style   <- if (exists("left_style"))   left_style   else border_style
+    right_color  <- if (exists("right_color"))  right_color  else border_color
+    right_style  <- if (exists("right_style"))  right_style  else border_style
+    top_color    <- if (exists("top_color"))    top_color    else border_color
+    top_style    <- if (exists("top_style"))    top_style    else border_style
+    bottom_color <- if (exists("bottom_color")) bottom_color else border_color
+    bottom_style <- if (exists("bottom_style")) bottom_style else border_style
 
     border <- create_border(
       left         = left_style,
@@ -783,7 +791,7 @@ create_dxfs_style <- function(
     "dxf",
     xml_children = c(
       font,
-      numFmt,
+      num_fmt,
       fill,
       border
     )
@@ -792,115 +800,123 @@ create_dxfs_style <- function(
 }
 
 #' create tableStyle
+#'
+#' Create a custom table style.
+#' This function is for expert use only. Use other styling functions instead.
+#'
 #' @param name name
-#' @param wholeTable wholeTable
-#' @param headerRow headerRow
-#' @param totalRow totalRow
-#' @param firstColumn firstColumn
-#' @param lastColumn lastColumn
-#' @param firstRowStripe firstRowStripe
-#' @param secondRowStripe secondRowStripe
-#' @param firstColumnStripe firstColumnStripe
-#' @param secondColumnStripe secondColumnStripe
-#' @param firstHeaderCell firstHeaderCell
-#' @param lastHeaderCell lastHeaderCell
-#' @param firstTotalCell firstTotalCell
-#' @param lastTotalCell lastTotalCell
+#' @param whole_table wholeTable
+#' @param header_row headerRow
+#' @param total_row totalRow
+#' @param first_column firstColumn
+#' @param last_column lastColumn
+#' @param first_row_stripe firstRowStripe
+#' @param second_row_stripe secondRowStripe
+#' @param first_column_stripe firstColumnStripe
+#' @param second_column_stripe secondColumnStripe
+#' @param first_header_cell firstHeaderCell
+#' @param last_header_cell lastHeaderCell
+#' @param first_total_cell firstTotalCell
+#' @param last_total_cell lastTotalCell
+#' @param ... additional arguments
 #' @export
 create_tablestyle <- function(
     name,
-    wholeTable         = NULL,
-    headerRow          = NULL,
-    totalRow           = NULL,
-    firstColumn        = NULL,
-    lastColumn         = NULL,
-    firstRowStripe     = NULL,
-    secondRowStripe    = NULL,
-    firstColumnStripe  = NULL,
-    secondColumnStripe = NULL,
-    firstHeaderCell    = NULL,
-    lastHeaderCell     = NULL,
-    firstTotalCell     = NULL,
-    lastTotalCell      = NULL
+    whole_table          = NULL,
+    header_row           = NULL,
+    total_row            = NULL,
+    first_column         = NULL,
+    last_column          = NULL,
+    first_row_stripe     = NULL,
+    second_row_stripe    = NULL,
+    first_column_stripe  = NULL,
+    second_column_stripe = NULL,
+    first_header_cell    = NULL,
+    last_header_cell     = NULL,
+    first_total_cell     = NULL,
+    last_total_cell      = NULL,
+    ...
 ) {
 
+  standardize_case_names(...)
+
   tab_wholeTable <- NULL
-  if (length(wholeTable)) {
+  if (length(whole_table)) {
     tab_wholeTable <- xml_node_create(
       "tableStyleElement",
-      xml_attributes = c(type = "wholeTable", dxfId = wholeTable))
+      xml_attributes = c(type = "wholeTable", dxfId = whole_table))
   }
   tab_headerRow <- NULL
-  if (length(headerRow)) {
+  if (length(header_row)) {
     tab_headerRow <- xml_node_create(
       "tableStyleElement",
-      xml_attributes = c(type = "headerRow", dxfId = headerRow))
+      xml_attributes = c(type = "headerRow", dxfId = header_row))
   }
   tab_totalRow <- NULL
-  if (length(totalRow)) {
+  if (length(total_row)) {
     tab_totalRow <- xml_node_create(
       "tableStyleElement",
-      xml_attributes = c(type = "totalRow", dxfId = totalRow))
+      xml_attributes = c(type = "totalRow", dxfId = total_row))
   }
   tab_firstColumn <- NULL
-  if (length(firstColumn)) {
+  if (length(first_column)) {
     tab_firstColumn <- xml_node_create(
       "tableStyleElement",
-      xml_attributes = c(type = "firstColumn", dxfId = firstColumn))
+      xml_attributes = c(type = "firstColumn", dxfId = first_column))
   }
   tab_lastColumn <- NULL
-  if (length(lastColumn)) {
+  if (length(last_column)) {
     tab_lastColumn <- xml_node_create(
       "tableStyleElement",
-      xml_attributes = c(type = "lastColumn", dxfId = lastColumn))
+      xml_attributes = c(type = "lastColumn", dxfId = last_column))
   }
   tab_firstRowStripe <- NULL
-  if (length(firstRowStripe)) {
+  if (length(first_row_stripe)) {
     tab_firstRowStripe <- xml_node_create(
       "tableStyleElement",
-      xml_attributes = c(type = "firstRowStripe", dxfId = firstRowStripe))
+      xml_attributes = c(type = "firstRowStripe", dxfId = first_row_stripe))
   }
   tab_secondRowStripe <- NULL
-  if (length(secondRowStripe)) {
+  if (length(second_row_stripe)) {
     tab_secondRowStripe <- xml_node_create(
       "tableStyleElement",
-      xml_attributes = c(type = "secondRowStripe", dxfId = secondRowStripe))
+      xml_attributes = c(type = "secondRowStripe", dxfId = second_row_stripe))
   }
   tab_firstColumnStripe <- NULL
-  if (length(firstColumnStripe)) {
+  if (length(first_column_stripe)) {
     tab_firstColumnStripe <- xml_node_create(
       "tableStyleElement",
-      xml_attributes = c(type = "firstColumnStripe", dxfId = firstColumnStripe))
+      xml_attributes = c(type = "firstColumnStripe", dxfId = first_column_stripe))
   }
   tab_secondColumnStripe <- NULL
-  if (length(secondColumnStripe)) {
+  if (length(second_column_stripe)) {
     tab_secondColumnStripe <- xml_node_create(
       "tableStyleElement",
-      xml_attributes = c(type = "secondColumnStripe", dxfId = secondColumnStripe))
+      xml_attributes = c(type = "secondColumnStripe", dxfId = second_column_stripe))
   }
   tab_firstHeaderCell <- NULL
-  if (length(firstHeaderCell)) {
+  if (length(first_header_cell)) {
     tab_firstHeaderCell <- xml_node_create(
       "tableStyleElement",
-      xml_attributes = c(type = "firstHeaderCell", dxfId = firstHeaderCell))
+      xml_attributes = c(type = "firstHeaderCell", dxfId = first_header_cell))
   }
   tab_lastHeaderCell <- NULL
-  if (length(lastHeaderCell)) {
+  if (length(last_header_cell)) {
     tab_lastHeaderCell <- xml_node_create(
       "tableStyleElement",
-      xml_attributes = c(type = "lastHeaderCell", dxfId = lastHeaderCell))
+      xml_attributes = c(type = "lastHeaderCell", dxfId = last_header_cell))
   }
   tab_firstTotalCell <- NULL
-  if (length(firstTotalCell)) {
+  if (length(first_total_cell)) {
     tab_firstTotalCell <- xml_node_create(
       "tableStyleElement",
-      xml_attributes = c(type = "firstTotalCell", dxfId = firstTotalCell))
+      xml_attributes = c(type = "firstTotalCell", dxfId = first_total_cell))
   }
   tab_lastTotalCell <- NULL
-  if (length(lastTotalCell)) {
+  if (length(last_total_cell)) {
     tab_lastTotalCell <- xml_node_create(
       "tableStyleElement",
-      xml_attributes = c(type = "lastTotalCell", dxfId = lastTotalCell))
+      xml_attributes = c(type = "lastTotalCell", dxfId = last_total_cell))
   }
 
   xml_elements <- c(
@@ -927,6 +943,7 @@ create_tablestyle <- function(
       name      = name,
       pivot     = "0", # pivot uses different styles
       count     = as_xml_attr(length(xml_elements)),
+       # possible st_guid()
       `xr9:uid` = sprintf("{CE23B8CA-E823-724F-9713-%s}", rand_str)
     ),
     xml_children = xml_elements
