@@ -66,7 +66,7 @@ test_that("removing leading chartsheets works", {
   # could be sheet 1, we keep it at 2. Otherwise our reference counter would get
   # in trouble. Similar things could happen if all worksheets are removed and
   # only chartsheets remain. Though that is currently not implemented.
-  fl <- system.file("extdata", "mtcars_chart.xlsx", package = "openxlsx2")
+  fl <- testfile_path("mtcars_chart.xlsx")
   tmp <- temp_xlsx()
   wb <- wb_load(fl)$
     remove_worksheet(1)
